@@ -2,7 +2,6 @@ package Test::RedisClusterBoot;
 use warnings;
 use strict;
 use Mouse;
-use namespace::autoclean;
 
 use IO::CaptureOutput qw/capture_exec/;
 use Sub::Retry;
@@ -15,7 +14,11 @@ use constant TEST_DOCKER_CONTAINER_NAME => 'test_for_perl_redis_cluster_fast';
 sub _die {
     my $string = shift;
     chomp $string;
-    die sprintf "[%s] %s", __PACKAGE__, $string;
+    my $message = join " ",
+        "Failed to create a docker container.",
+        "You can set a TEST_REDIS_CLUSTER_STARTUP_NODES environment to specify redis cluster nodes manually.",
+        "(e.g. TEST_REDIS_CLUSTER_STARTUP_NODES=localhost:9000,localhost:9001,localhost:9002 )";
+    die sprintf "[%s] %s ERR: %s", __PACKAGE__, $message, $string;
 }
 
 sub docker_run {
@@ -38,14 +41,18 @@ sub docker_run {
                 capture_exec(qw/docker rm/, $1);
                 return 1;
             }
-            _die("unknown error $stderr") if $stderr;
+            if ($stderr) {
+                _die($stderr);
+                return 1;
+            }
             return 0;
         }
     );
 
-    _die("cannot run test docker container")
+    _die("container_id undefined")
         unless defined $container_id;
     return $container_id;
 }
 
+no Mouse;
 1;
